@@ -1,3 +1,30 @@
+/*
+ *
+ * Copyright (c) 2007-2016 The University of Waikato, Hamilton, New Zealand.
+ * All rights reserved.
+ *
+ * This file is part of libtrace.
+ *
+ * This code has been developed by the University of Waikato WAND
+ * research group. For further information please see http://www.wand.net.nz/
+ *
+ * libtrace is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * libtrace is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ *
+ */
+
+
 #define OPTIMISE 1
 #define OUTPUT_COMPILED 0
 
@@ -568,7 +595,7 @@ void initialise_array(void)
 	opcode_names[BPF_RET+BPF_K]		= "bpf_ret_k";
 
 	opcode_names[BPF_MISC+BPF_TAX]		= "bpf_tax";
-	opcode_names[BPF_MISC+BPF_TXA]		= "bpf_tax";
+	opcode_names[BPF_MISC+BPF_TXA]		= "bpf_txa";
 
 }
 
