@@ -112,26 +112,27 @@
  * @version $Id$
  *
  * Not too much detail required with these functions - this header file exists
- * solely to ensure that we don't have to duplicate the same code across 
+ * solely to ensure that we don't have to duplicate the same code across
  * multiple format modules.
  */
 
 typedef struct dag_section_header {
-        uint16_t type;
-        uint16_t len;
+    uint16_t type;
+    uint16_t len;
 } PACKED dag_sec_t;
 ct_assert(sizeof(dag_sec_t) == 4);
 
 struct dag_opthdr {
-        uint16_t optcode;
-        uint16_t optlen;
+    uint16_t optcode;
+    uint16_t optlen;
 } PACKED;
 ct_assert(sizeof(struct dag_opthdr) == 4);
 
 int erf_get_framing_length(const libtrace_packet_t *packet);
 libtrace_linktype_t erf_get_link_type(const libtrace_packet_t *packet);
 libtrace_direction_t erf_get_direction(const libtrace_packet_t *packet);
-libtrace_direction_t erf_set_direction(libtrace_packet_t *packet, libtrace_direction_t direction);
+libtrace_direction_t erf_set_direction(libtrace_packet_t *packet,
+                                       libtrace_direction_t direction);
 uint64_t erf_get_erf_timestamp(const libtrace_packet_t *packet);
 int erf_get_capture_length(const libtrace_packet_t *packet);
 int erf_get_wire_length(const libtrace_packet_t *packet);
@@ -139,7 +140,7 @@ size_t erf_set_capture_length(libtrace_packet_t *packet, size_t size);
 int erf_is_color_type(uint8_t erf_type);
 libtrace_meta_t *erf_get_all_meta(libtrace_packet_t *packet);
 bool find_compatible_linktype(libtrace_out_t *libtrace,
-        libtrace_packet_t *packet);
+                              libtrace_packet_t *packet);
 int erf_get_padding(const libtrace_packet_t *packet);
 
 #endif
