@@ -10,26 +10,27 @@
  * as accessed via the /proc/net/dev
  */
 struct linux_dev_stats {
-        char if_name[IF_NAMESIZE];
-        uint64_t rx_bytes;
-        uint64_t rx_packets;
-        uint64_t rx_errors;
-        uint64_t rx_drops;
-        uint64_t rx_fifo;
-        uint64_t rx_frame;
-        uint64_t rx_compressed;
-        uint64_t rx_multicast;
-        uint64_t tx_bytes;
-        uint64_t tx_packets;
-        uint64_t tx_errors;
-        uint64_t tx_drops;
-        uint64_t tx_fifo;
-        uint64_t tx_colls;
-        uint64_t tx_carrier;
-        uint64_t tx_compressed;
+    char if_name[IF_NAMESIZE];
+    uint64_t rx_bytes;
+    uint64_t rx_packets;
+    uint64_t rx_errors;
+    uint64_t rx_drops;
+    uint64_t rx_fifo;
+    uint64_t rx_frame;
+    uint64_t rx_compressed;
+    uint64_t rx_multicast;
+    uint64_t tx_bytes;
+    uint64_t tx_packets;
+    uint64_t tx_errors;
+    uint64_t tx_drops;
+    uint64_t tx_fifo;
+    uint64_t tx_colls;
+    uint64_t tx_carrier;
+    uint64_t tx_compressed;
 };
 
-int linux_set_nic_promisc(const int sock, const unsigned int ifindex, bool enable);
+int linux_set_nic_promisc(const int sock, const unsigned int ifindex,
+                          bool enable);
 int linux_get_nic_max_queues(char *ifname);
 int linux_get_nic_queues(char *ifname);
 int linux_set_nic_queues(char *ifname, int queues);
