@@ -569,7 +569,7 @@ static int accept_ndagtcp_connection(libtrace_t *libtrace, char *ipstr,
             consock = 0;
             continue;
         }
-
+        addrsize = sizeof(struct sockaddr_storage);
         consock = accept(sock, (struct sockaddr *)&sa, &addrsize);
         if (consock < 0) {
             fprintf(stderr,
@@ -648,6 +648,7 @@ static void *ndagtcp_controller_run(void *tdata)
     libtrace_t *libtrace = (libtrace_t *)tdata;
     int sock = -1;
 
+    ndag_paused = 0;
     while (is_halted(libtrace) == -1 && !ndag_paused) {
         sock = accept_ndagtcp_connection(libtrace, FORMAT_DATA->multicastgroup,
                                          FORMAT_DATA->portstr);
@@ -933,6 +934,7 @@ static unsigned int copy_tmp_buffer(streamsock_t *ssock, char *tmpbuf,
         }
         memcpy(ptr, ssock->saved[next], ssock->savedsize[next]);
         available += ssock->savedsize[next];
+        ptr += ssock->savedsize[next];
     }
     return available;
 }
@@ -1376,6 +1378,7 @@ static int add_new_streamsock(libtrace_t *libtrace, recvstream_t *rt,
     ssock->reccount = 0;
     ssock->expectedreccount = 0;
     ssock->rectype = 0;
+    ssock->srcaddr = NULL;
 
     for (i = 0; i < ENCAP_BUFFERS; i++) {
         ssock->saved[i] = (char *)malloc(ENCAP_BUFSIZE);
@@ -1452,6 +1455,13 @@ static int receiver_read_messages(libtrace_t *libtrace, recvstream_t *rt,
 static inline int readable_data(streamsock_t *ssock)
 {
 
+    /* Don't read from a buffer belonging to a socket that we've closed,
+     * since we probably closed it for sending us garbage data...
+     */
+    if (ssock->sock == -1) {
+        return 0;
+    }
+
     if (ssock->bufavail == ENCAP_BUFFERS) {
         return 0;
     }
@@ -1478,6 +1488,9 @@ static int init_receivers(streamsock_t *ssock, int required)
 #if HAVE_DECL_RECVMMSG
     for (i = 0; i < required; i++) {
         if (ssock->socktype != NDAG_SOCKET_TYPE_MULTICAST) {
+            ssock->singlemsg.msg_iov->iov_base = ssock->saved[wind];
+            ssock->singlemsg.msg_iov->iov_len = ENCAP_BUFSIZE;
+            ssock->singlemsg.msg_iovlen = 1;
             i = 1;
             break;
         }
@@ -1496,10 +1509,11 @@ static int init_receivers(streamsock_t *ssock, int required)
 
         wind++;
     }
-#endif
+#else
     ssock->singlemsg.msg_iov->iov_base = ssock->saved[wind];
     ssock->singlemsg.msg_iov->iov_len = ENCAP_BUFSIZE;
     ssock->singlemsg.msg_iovlen = 1;
+#endif
     return i;
 }
 
@@ -1777,13 +1791,14 @@ static int receive_encap_records_nonblock(libtrace_t *libtrace,
     return receive_from_sockets(rt, FORMAT_DATA->socktype);
 }
 
-static streamsock_t *select_next_packet(recvstream_t *rt)
+static streamsock_t *select_next_packet(recvstream_t *rt, int *errstate)
 {
     int i, r;
     streamsock_t *ssock = NULL;
     uint64_t earliest = 0;
     uint64_t currentts = 0;
 
+    *errstate = 0;
     for (i = 0; i < rt->sourcecount; i++) {
         if (!readable_data(&(rt->sources[i]))) {
             continue;
@@ -1792,6 +1807,9 @@ static streamsock_t *select_next_packet(recvstream_t *rt)
         if (rt->sources[i].rectype == 0) {
             r = process_ndag_encap_headers(&(rt->sources[i]), rt);
             if (r < 0) {
+                close(rt->sources[i].sock);
+                rt->sources[i].sock = -1;
+                *errstate = 1;
                 return NULL;
             }
             if (r == 0) {
@@ -1809,6 +1827,9 @@ static streamsock_t *select_next_packet(recvstream_t *rt)
             }
 
             if (r < 0) {
+                close(rt->sources[i].sock);
+                rt->sources[i].sock = -1;
+                *errstate = 1;
                 return NULL;
             }
             if (r == 0) {
@@ -1832,7 +1853,7 @@ static streamsock_t *select_next_packet(recvstream_t *rt)
 static int ndag_read_packet(libtrace_t *libtrace, libtrace_packet_t *packet)
 {
 
-    int rem, ret;
+    int rem, ret, errstate;
     streamsock_t *nextavail = NULL;
 
     if (FORMAT_DATA->receivers[0].halted) {
@@ -1846,8 +1867,14 @@ static int ndag_read_packet(libtrace_t *libtrace, libtrace_packet_t *packet)
         return rem;
     }
 
-    nextavail = select_next_packet(&(FORMAT_DATA->receivers[0]));
+    errstate = 0;
+    nextavail = select_next_packet(&(FORMAT_DATA->receivers[0]), &errstate);
     if (nextavail == NULL) {
+        if (errstate) {
+            trace_set_err(libtrace, TRACE_ERR_BAD_PACKET,
+                    "Error while parsing nDAG PDU");
+            return READ_ERROR;
+        }
         return READ_MESSAGE;
     }
 
@@ -1867,7 +1894,7 @@ static int ndag_pread_packets(libtrace_t *libtrace, libtrace_thread_t *t,
 {
 
     recvstream_t *rt;
-    int rem, i, r;
+    int rem, i, r, errstate;
     size_t read_packets = 0;
     streamsock_t *nextavail = NULL;
 
@@ -1901,8 +1928,14 @@ static int ndag_pread_packets(libtrace_t *libtrace, libtrace_thread_t *t,
                 break;
             }
         }
-        nextavail = select_next_packet(rt);
+        errstate = 0;
+        nextavail = select_next_packet(rt, &errstate);
         if (nextavail == NULL) {
+            if (errstate) {
+                trace_set_err(libtrace, TRACE_ERR_BAD_PACKET,
+                        "Error while parsing nDAG PDU");
+                return -1;
+            }
             continue;
         }
 
@@ -1946,7 +1979,7 @@ static libtrace_eventobj_t trace_event_ndag(libtrace_t *libtrace,
 {
 
     libtrace_eventobj_t event = {0, 0, 0.0, 0};
-    int rem, i;
+    int rem, i, errstate;
     streamsock_t *nextavail = NULL;
 
     if (FORMAT_DATA->receivers[0].halted) {
@@ -1984,10 +2017,17 @@ static libtrace_eventobj_t trace_event_ndag(libtrace_t *libtrace,
             break;
         }
 
-        nextavail = select_next_packet(&(FORMAT_DATA->receivers[0]));
+        errstate = 0;
+        nextavail = select_next_packet(&(FORMAT_DATA->receivers[0]), &errstate);
         if (nextavail == NULL) {
-            event.type = TRACE_EVENT_SLEEP;
-            event.seconds = 0.0001;
+            if (errstate) {
+                trace_set_err(libtrace, TRACE_ERR_BAD_PACKET,
+                        "Error while parsing nDAG PDU");
+                event.type = TRACE_EVENT_TERMINATE;
+            } else {
+                event.type = TRACE_EVENT_SLEEP;
+                event.seconds = 0.0001;
+            }
             break;
         }
 
